# -*- coding: utf-8 -*-

"""pai2 URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.8/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Add an import:  from blog import urls as blog_urls
    2. Add a URL to urlpatterns:  url(r'^blog/', include(blog_urls))
"""
from django.conf import settings
from django.conf.urls import include, url
from django.conf.urls.static import static
from django.contrib import admin

from rest_framework import routers
from account import views as account_views
from group import views as group_views
from photo import views as photo_views

router = routers.DefaultRouter()
# router.register(r'users', account_views.UserViewSet)
# router.register(r'groups', account_views.GroupViewSet)

router.register(r'lensmans', account_views.LensmanInfoViewSet)
router.register(r'users', account_views.UserInfoViewSet)

router.register(r'groups', group_views.GroupInfoViewSet)
router.register(r'group_users', group_views.GroupUserInfoViewSet)
router.register(r'group_photos', group_views.GroupPhotoInfoViewSet)

router.register(r'photos', photo_views.PhotoInfoViewSet)

urlpatterns = [
    url(r'^pai2admin/', include(admin.site.urls)),
]

urlpatterns += [
    # url(r'^api/', include('api.urls', namespace='api')),
    url(r'^s/(?P<session>\w+)$', photo_views.session_detail, name='session_detail'),  # Session 详情
    url(r'^p/(?P<photo>\w+)$', photo_views.photo_standard, name='photo_standard'),  # standard thumbnail, available for free
    url(r'^m/(?P<photo>\w+)$', photo_views.photo_medium, name='photo_medium'),  # medium/mobile version, without watermark, login or paid by others
    url(r'^l/(?P<photo>\w+)$', photo_views.photo_large, name='photo_large'),  # large, might support server side panning later, login required
    url(r'^r/(?P<photo>\w+)$', photo_views.photo_raw, name='photo_raw'),  # raw image, only for finishers
]

# Wire up our API using automatic URL routing.
# Additionally, we include login URLs for the browsable API.
urlpatterns += [
    url(r'^api/', include(router.urls)),
    url(r'^api-auth/', include('rest_framework.urls', namespace='rest_framework'))
]

urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
